package io.renren.modules.app.dao;

import io.renren.modules.app.entity.HZzsyfpEntity;
import com.baomidou.mybatisplus.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 增值收益分配表
 *
 * @author ly
 * @email 1271428398@qq.com
 * @date 2019-06-14 16:09:48
 */
@Mapper
public interface HZzsyfpDao extends BaseMapper<HZzsyfpEntity> {

    /**
     * 分页模糊查询
     * @param hZzsyfpEntity
     * @return
     */
    List<HZzsyfpEntity> queryByPage(HZzsyfpEntity hZzsyfpEntity);
    
    /**
     * 资产收益分配公式修改
     * @param hZzsyfpEntity
     * @return
     */
    int updateZZSYFP(HZzsyfpEntity hZzsyfpEntity);

    /**
	 * NC
	 * @return
	 */
	String selectNC(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectQC(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectQM_1(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectQM_else2(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectQM_else1(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectJF(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectDF(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectBNJF(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectBNDF(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj,@Param("kmdm")String kmdm);
	
	String selectKJQJ(@Param("ztbm")String ztbm,@Param("kjqj")String kjqj);
}
